package br.com.ages.mutiraodobemback.domain;

import br.com.ages.mutiraodobemback.dto.EventRequestDTO;
import br.com.ages.mutiraodobemback.util.Validations;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.mapping.Document;
import org.springframework.lang.NonNull;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@Document(collection = "events")
public class EventEntity {

    @Id
    private String id;
    @NonNull
    private String title;
    @NonNull
    private String description;
//    @NonNull
    private AddresEntity address;
    @NonNull
    private String phone;
    @NonNull
    private LocalDateTime startDate;
    @NonNull
    private LocalDateTime endDate;
    @NonNull
    private LocalDateTime createdDate;
    @NonNull
    private List<String> images;
    @NonNull
    private List<TaskEntity> tasks;
    @NonNull
    private UserEntity user;
    @NonNull
    private String eventType;
    @NonNull
    private boolean active;
    @NonNull
    private List<UserEntity> volunteer;

    public EventEntity(EventRequestDTO event) {
        this.title = event.getTitle();
        this.address = AddresEntity.builder().street(event.getStreet()).latitude(event.getLatitude()).longitude(event.getLongitude()).build();
        this.createdDate = LocalDateTime.now();
        this.startDate = event.getStartDate();
        this.endDate = event.getEndDate();
        this.description = event.getDescription();
//        this.images = event.getImages();
        this.tasks = event.getTasks();

//        this.eventType = event.getEventType();
    }

    public void addImage(String image) {
        if (Validations.isNull(this.images)) this.images = new ArrayList<>();
        this.images.add(image);
    }

}