package br.com.ages.mutiraodobemback.security;

import br.com.ages.mutiraodobemback.util.MD5PasswordEncoder;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.http.HttpMethod;
import org.springframework.security.config.annotation.authentication.builders.AuthenticationManagerBuilder;
import org.springframework.security.config.annotation.web.builders.HttpSecurity;
import org.springframework.security.config.annotation.web.configuration.EnableWebSecurity;
import org.springframework.security.config.annotation.web.configuration.WebSecurityConfigurerAdapter;
import org.springframework.security.core.userdetails.UserDetailsService;
import org.springframework.security.web.authentication.UsernamePasswordAuthenticationFilter;
import org.springframework.security.web.util.matcher.RequestMatcher;

@Configuration
@EnableWebSecurity
public class WebSecurityConfig extends WebSecurityConfigurerAdapter {

    @Autowired
    @Qualifier("userDetailsService")
    private UserDetailsService userDetailsService;

    @Bean
    public static MD5PasswordEncoder passwordEncoder() {
        return new MD5PasswordEncoder();
    }

    @Override
    protected void configure(HttpSecurity http) throws Exception {

        http.csrf().disable()
//            .antMatcher("/all-active")
            .authorizeRequests()
            .antMatchers(HttpMethod.GET, "/",
                "/v2/api-docs",
                "/configuration/ui",
                "/swagger-resources/**",
                "/configuration/security",
                "/swagger-ui.html",
                "/webjars/**").permitAll()
                .antMatchers(HttpMethod.POST,"/users").permitAll()
            .antMatchers(HttpMethod.GET,"/users").access("hasAnyRole('USER','ADMIN')")
            .antMatchers(HttpMethod.GET,"/events/all-active").permitAll()
            .antMatchers(HttpMethod.POST, "/events/upload-image").permitAll()
            .antMatchers(HttpMethod.GET,"/events").access("hasAnyRole('USER','ADMIN')")
            .antMatchers(HttpMethod.GET,"/events/{id}").access("hasAnyRole('USER','ADMIN')")
            .antMatchers(HttpMethod.POST,"/events").access("hasAnyRole('USER','ADMIN')")
            .antMatchers(HttpMethod.PUT,"/events").access("hasAnyRole('USER','ADMIN')")
            .anyRequest()
            .authenticated()
            .and().cors()
            .and()
//            .formLogin()
//            .and()
//            .logout()
//            .logoutRequestMatcher(new AntPathRequestMatcher("/logout"))
//            .logoutSuccessUrl("/login").permitAll();
//            .and()
            .addFilterAfter(new JWTLoginFilter("/users/login", authenticationManager()), UsernamePasswordAuthenticationFilter.class)
            .addFilterAfter(new JWTAuthenticatorFilter(), UsernamePasswordAuthenticationFilter.class);
    }

    @Override
    protected void configure(AuthenticationManagerBuilder auth) throws Exception {
        auth.inMemoryAuthentication()
            .withUser("admin")
            .password(passwordEncoder().encode("admin"))
            .roles("ADMIN");
        auth.userDetailsService(userDetailsService)
            .passwordEncoder(passwordEncoder());
    }

}
